"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUsage = void 0;
const ejs_1 = require("ejs");
const path_1 = require("path");
const fs_1 = require("fs");
const renderUsageTemplate = (0, ejs_1.compile)((0, fs_1.readFileSync)((0, path_1.join)(__dirname, '../template.web-components.ejs'), 'utf8'), {
    filename: 'template.web-components.ejs',
    async: true,
});
function jsonEscapeChars(jsonString) {
    return jsonString
        .replace(/\\n/g, '\\n')
        .replace(/\\'/g, "\\'")
        .replace(/\\"/g, '\\"')
        .replace(/\\&/g, '\\&')
        .replace(/\\r/g, '\\r')
        .replace(/\\t/g, '\\t')
        .replace(/\\b/g, '\\b')
        .replace(/\\f/g, '\\f')
        .replaceAll('"', "'");
}
function tryParseJSONObject(jsonString) {
    try {
        const object = JSON.parse(jsonString);
        if (object && typeof object === 'object') {
            return true;
        }
    }
    catch (exception) {
        return false;
    }
    return false;
}
async function getUsage(data) {
    const props = Object.keys(data.props || {}).map((key) => {
        const value = data.props[key];
        return {
            key,
            value,
        };
    });
    const attributes = props
        .map(({ key, value }) => {
        switch (typeof value) {
            case 'string': {
                const isValueJSON = tryParseJSONObject(value);
                // escaping double quotes
                const processedValue = isValueJSON
                    ? jsonEscapeChars(value.replaceAll('"', "'"))
                    : value;
                return `${key}="${processedValue}"`;
            }
            case 'boolean':
                return value ? `${key}` : '';
            default:
                return `${key}="${jsonEscapeChars(JSON.stringify(value))}"`;
        }
    })
        .filter(Boolean)
        .join(' ');
    const { templateName, children, before, after } = data;
    const result = await renderUsageTemplate({
        templateName,
        attributes,
        props,
        children,
        before,
        after,
    });
    return result.trim();
}
exports.getUsage = getUsage;
//# sourceMappingURL=utils.js.map